@@ -88,8 +88,9 @@ class TestOLT(unittest.TestCase):
         pon_port = olt.module.next_neu.data.interfaces.add()
         pon = pon_port.pons.add()
         pon.id = '100001'
+        pon.name = 'GPON 100001'
         self._await(olt.load())
-        exp_ref = NetworkMetadataReference(type='ap', value='TestAP.100001', attributes={'topology1': 'PON.100001', 'topology2': 'OLT.TestAP', 'ap_config': 'TestAP.100001', 'topology1_snmp': 'TestAP', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='TestAP.100001', attributes={'topology1': 'GPON 100001', 'topology2': 'OLT.TestAP', 'ap_config': 'TestAP.100001', 'topology1_snmp': 'TestAP', 'system': 'net'})
         ap_refs = self.ctx.netmeta_model.refs.get('ap') or {}
         self.assertEqual(len(ap_refs), 1)
         self.assertEqual(ap_refs.get('TestAP.100001'), exp_ref)
@@ -148,16 +149,17 @@ class TestOLT(unittest.TestCase):
     def test_olt_bootstrap(self):
         """An OLT reads its previous state on initialization."""
         # Create existing state (that will no longer be present)
-        cur_ref = NetworkMetadataReference(type='ap', value='TestAP.100001', attributes={'topology1': 'PON.100001', 'topology2': 'OLT.TestAP', 'ap_config': 'TestAP.100001', 'topology1_snmp': 'TestAP', 'system': 'net'})
+        cur_ref = NetworkMetadataReference(type='ap', value='TestAP.100001', attributes={'topology1': 'GPON 100001', 'topology2': 'OLT.TestAP', 'ap_config': 'TestAP.100001', 'topology1_snmp': 'TestAP', 'system': 'net'})
         self._await(self.ctx.netmeta_model.set_ref(cur_ref))
         olt = Olt(self.ctx, 'TestAP', 'TestAP', 'MySite', FakeClient('MyHost'), None, 'olt', None)
         olt.module = FakeModule()
         pon_port = olt.module.next_neu.data.interfaces.add()
         pon = pon_port.pons.add()
         pon.id = '100002'
+        pon.name = 'GPON 100002'
         self._await(olt.load())
         # old state should be removed and new state created
-        exp_ref = NetworkMetadataReference(type='ap', value='TestAP.100002', attributes={'topology1': 'PON.100002', 'topology2': 'OLT.TestAP', 'ap_config': 'TestAP.100002', 'topology1_snmp': 'TestAP', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='TestAP.100002', attributes={'topology1': 'GPON 100002', 'topology2': 'OLT.TestAP', 'ap_config': 'TestAP.100002', 'topology1_snmp': 'TestAP', 'system': 'net'})
         ap_refs = self.ctx.netmeta_model.refs.get('ap') or {}
         self.assertEqual(len(ap_refs), 1)
         self.assertEqual(ap_refs.get('TestAP.100002'), exp_ref)
@@ -198,8 +200,9 @@ class TestOLT(unittest.TestCase):
         pon_port = olt.module.next_neu.data.interfaces.add()
         pon = pon_port.pons.add()
         pon.id = '100001'
+        pon.name = 'GPON 100001'
         self._await(olt.load())
-        exp_ref = NetworkMetadataReference(type='ap', value='TestAP.100001', attributes={'topology1': 'PON.100001', 'topology2': 'OLT.TestAP', 'ap_config': 'TestAP.100001', 'topology1_snmp': 'TestAP', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='TestAP.100001', attributes={'topology1': 'GPON 100001', 'topology2': 'OLT.TestAP', 'ap_config': 'TestAP.100001', 'topology1_snmp': 'TestAP', 'system': 'net'})
         ap_refs = self.ctx.netmeta_model.refs.get('ap') or {}
         self.assertEqual(len(ap_refs), 1)
         self.assertEqual(ap_refs.get('TestAP.100001'), exp_ref)
@@ -226,6 +229,7 @@ class TestOLT(unittest.TestCase):
             ont_pon_port = ont.interfaces.add()
             ont_pon = ont_pon_port.pons.add()
             ont_pon.id = pon_id
+            ont_pon.name = f"GPON {pon_id}"
             ont_pon.poller_hash = ont_pon.id.encode()
             olt_link = pon_port.links.add()
             olt_link.poller_hash = ont_pon_port.poller_hash
@@ -248,6 +252,7 @@ class TestOLT(unittest.TestCase):
         pon_port = olt1.module.next_neu.data.interfaces.add()
         pon = pon_port.pons.add()
         pon.id = '100001'
+        pon.name = f"GPON {pon.id}"
         pon.poller_hash = b'100001'
         brmacs = ['00:01:00:00:00:01'] if bridged_macs else None
         add_ont(olt1.module.next_neu, pon_port, pon, '000002000001', brmacs, None)
@@ -258,6 +263,7 @@ class TestOLT(unittest.TestCase):
         pon_port = pon_card.interfaces.add()
         pon = pon_port.pons.add()
         pon.id = '200001'
+        pon.name = f"GPON {pon.id}"
         pon.poller_hash = b'200001'
         brmacs = ['00:01:00:00:00:02', '00:01:00:00:00:03'] if bridged_macs else None
         add_ont(olt2.module.next_neu, pon_port, pon, '000003000001', None, brmacs)
@@ -279,6 +285,7 @@ class TestOLT(unittest.TestCase):
         pon_port.poller_hash = b'olt4-1'
         pon = pon_port.pons.add()
         pon.id = '400001'
+        pon.name = f"GPON {pon.id}"
         pon.poller_hash = b'400001'
 
         self.aps = []
@@ -352,11 +359,11 @@ class TestOLT(unittest.TestCase):
 
         ap_refs = self.ctx.netmeta_model.refs.get('ap') or {}
         self.assertEqual(len(ap_refs), 3)
-        exp_ref = NetworkMetadataReference(type='ap', value='olt1.100001', attributes={'topology1': 'PON.100001', 'topology2': 'OLT.olt1', 'ap_config': 'olt1.100001', 'topology1_snmp': 'olt1', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='olt1.100001', attributes={'topology1': 'GPON 100001', 'topology2': 'OLT.olt1', 'ap_config': 'olt1.100001', 'topology1_snmp': 'olt1', 'system': 'net'})
         self.assertEqual(ap_refs.get('olt1.100001'), exp_ref)
-        exp_ref = NetworkMetadataReference(type='ap', value='olt2.200001', attributes={'topology1': 'PON.200001', 'topology2': 'OLT.olt2', 'ap_config': 'olt2.200001', 'topology1_snmp': 'olt2', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='olt2.200001', attributes={'topology1': 'GPON 200001', 'topology2': 'OLT.olt2', 'ap_config': 'olt2.200001', 'topology1_snmp': 'olt2', 'system': 'net'})
         self.assertEqual(ap_refs.get('olt2.200001'), exp_ref)
-        exp_ref = NetworkMetadataReference(type='ap', value='olt4.400001', attributes={'topology1': 'PON.400001', 'topology2': 'OLT.olt4', 'ap_config': 'olt4.400001', 'topology1_snmp': 'olt4', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='olt4.400001', attributes={'topology1': 'GPON 400001', 'topology2': 'OLT.olt4', 'ap_config': 'olt4.400001', 'topology1_snmp': 'olt4', 'system': 'net'})
         self.assertEqual(ap_refs.get('olt4.400001'), exp_ref)
 
         # check bridged macs
@@ -444,11 +451,11 @@ class TestOLT(unittest.TestCase):
 
         ap_refs = self.ctx.netmeta_model.refs.get('ap') or {}
         self.assertEqual(len(ap_refs), 3)
-        exp_ref = NetworkMetadataReference(type='ap', value='olt1.100001', attributes={'topology1': 'PON.100001', 'topology2': 'OLT.olt1', 'ap_config': 'olt1.100001', 'topology1_snmp': 'olt1', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='olt1.100001', attributes={'topology1': 'GPON 100001', 'topology2': 'OLT.olt1', 'ap_config': 'olt1.100001', 'topology1_snmp': 'olt1', 'system': 'net'})
         self.assertEqual(ap_refs.get('olt1.100001'), exp_ref)
-        exp_ref = NetworkMetadataReference(type='ap', value='olt2.200001', attributes={'topology1': 'PON.200001', 'topology2': 'OLT.olt2', 'ap_config': 'olt2.200001', 'topology1_snmp': 'olt2', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='olt2.200001', attributes={'topology1': 'GPON 200001', 'topology2': 'OLT.olt2', 'ap_config': 'olt2.200001', 'topology1_snmp': 'olt2', 'system': 'net'})
         self.assertEqual(ap_refs.get('olt2.200001'), exp_ref)
-        exp_ref = NetworkMetadataReference(type='ap', value='olt4.400001', attributes={'topology1': 'PON.400001', 'topology2': 'OLT.olt4', 'ap_config': 'olt4.400001', 'topology1_snmp': 'olt4', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='olt4.400001', attributes={'topology1': 'GPON 400001', 'topology2': 'OLT.olt4', 'ap_config': 'olt4.400001', 'topology1_snmp': 'olt4', 'system': 'net'})
         self.assertEqual(ap_refs.get('olt4.400001'), exp_ref)
 
         # check bridged macs
@@ -475,11 +482,11 @@ class TestOLT(unittest.TestCase):
 
         ap_refs = self.ctx.netmeta_model.refs.get('ap') or {}
         self.assertEqual(len(ap_refs), 3)
-        exp_ref = NetworkMetadataReference(type='ap', value='olt1.100001', attributes={'topology1': 'PON.100001', 'topology2': 'OLT.olt1', 'ap_config': 'olt1.100001', 'topology1_snmp': 'olt1', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='olt1.100001', attributes={'topology1': 'GPON 100001', 'topology2': 'OLT.olt1', 'ap_config': 'olt1.100001', 'topology1_snmp': 'olt1', 'system': 'net'})
         self.assertEqual(ap_refs.get('olt1.100001'), exp_ref)
-        exp_ref = NetworkMetadataReference(type='ap', value='olt2.200001', attributes={'topology1': 'PON.200001', 'topology2': 'OLT.olt2', 'ap_config': 'olt2.200001', 'topology1_snmp': 'olt2', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='olt2.200001', attributes={'topology1': 'GPON 200001', 'topology2': 'OLT.olt2', 'ap_config': 'olt2.200001', 'topology1_snmp': 'olt2', 'system': 'net'})
         self.assertEqual(ap_refs.get('olt2.200001'), exp_ref)
-        exp_ref = NetworkMetadataReference(type='ap', value='olt4.400001', attributes={'topology1': 'PON.400001', 'topology2': 'OLT.olt4', 'ap_config': 'olt4.400001', 'topology1_snmp': 'olt4', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='olt4.400001', attributes={'topology1': 'GPON 400001', 'topology2': 'OLT.olt4', 'ap_config': 'olt4.400001', 'topology1_snmp': 'olt4', 'system': 'net'})
         self.assertEqual(ap_refs.get('olt4.400001'), exp_ref)
 
         # check bridged macs
@@ -504,11 +511,11 @@ class TestOLT(unittest.TestCase):
 
         ap_refs = self.ctx.netmeta_model.refs.get('ap') or {}
         self.assertEqual(len(ap_refs), 3)
-        exp_ref = NetworkMetadataReference(type='ap', value='olt1.100001', attributes={'topology1': 'PON.100001', 'topology2': 'OLT.olt1', 'ap_config': 'olt1.100001', 'topology1_snmp': 'olt1', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='olt1.100001', attributes={'topology1': 'GPON 100001', 'topology2': 'OLT.olt1', 'ap_config': 'olt1.100001', 'topology1_snmp': 'olt1', 'system': 'net'})
         self.assertEqual(ap_refs.get('olt1.100001'), exp_ref)
-        exp_ref = NetworkMetadataReference(type='ap', value='olt2.200001', attributes={'topology1': 'PON.200001', 'topology2': 'OLT.olt2', 'ap_config': 'olt2.200001', 'topology1_snmp': 'olt2', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='olt2.200001', attributes={'topology1': 'GPON 200001', 'topology2': 'OLT.olt2', 'ap_config': 'olt2.200001', 'topology1_snmp': 'olt2', 'system': 'net'})
         self.assertEqual(ap_refs.get('olt2.200001'), exp_ref)
-        exp_ref = NetworkMetadataReference(type='ap', value='olt4.400001', attributes={'topology1': 'PON.400001', 'topology2': 'OLT.olt4', 'ap_config': 'olt4.400001', 'topology1_snmp': 'olt4', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='olt4.400001', attributes={'topology1': 'GPON 400001', 'topology2': 'OLT.olt4', 'ap_config': 'olt4.400001', 'topology1_snmp': 'olt4', 'system': 'net'})
         self.assertEqual(ap_refs.get('olt4.400001'), exp_ref)
 
         # check bridged macs
